## Alice ChangeLog

Here you can see the full list of changes between each Alice release.


##### Version 1.6.1, 1.6.2, 16.3
- Minor enhancement for better logging in case, wrong config is passed
- code channel name separation from alert channel

##### Version 1.6
- Added Features
  - Notify if sensitive files modified
  - Notify Code Freeze
  - Notify QA SignOff
  - Personal Reminder on following Release process when merged to any of sensitive branch

##### Version 1.5
- updated docs
- fixed a bug with PR open

##### Version 1.4
First public release
- PyPi support for anyone to install easily

##### Version 1.3
- added doc strings for more readability
- small corrections
- code cleanup

##### Version 1.0, 1.1, 1.2
On the fly checks like:

- tech_review
- product_review
- close_dangerous_pr
- comment_guidelines
- notify_lead_on_given_action
- notify_channel_on_merge
- notify_on_sensitive_files_touched
- remind_direct_release_guideline_on_merge



